//
//  Sps.h
//  Sps
//
//  Created by Mobeleader on 09/07/12.
//  Copyright (c) 2012 Beleader Internet Marketing S.L. All rights reserved.
//

//To enable Location manager since iOS 8 you need to add in your Info.plist file this key "NSLocationWhenInUseUsageDescription" with this description "Location is required to find out where you are"

#import <Foundation/Foundation.h>
#import <QuartzCore/QuartzCore.h>
#import <CoreLocation/CoreLocation.h>
#import <UIKit/UIKit.h>
#import <MediaPlayer/MediaPlayer.h>
#import <WebKit/WebKit.h>


//Protocol to know what is happening on the library
@protocol SpsDelegate
@optional

//Optional function to implement something when SpS is Active for this app in mobeleader panel
-(void)onActive;

//Optional function to implement something when SpS is Inactive for this app in mobeleader panel
-(void)onInactive;

//Optional function to implement something when the library is started and is going to fetch advertisements
-(void)onLibStart;

//Optional function to implement something when the library is not going to show any advetisement
-(void)onAdNotShow;

//Optional function to implement something when the library is not going to show any advetisement
-(void)onAdNotShow:(NSDictionary *) returnedDictionary;

//Optional function to implement something when the library is going to show an advertisement
-(void)onAdShow;

//Optional function to implement something when the library is ready to show the advetisement.
//The adType variable contains advertisement type
-(void)onAdReadyToShow:(NSString *) adType;

//Optional function to implement something when the advetisement is present on screen
-(void)onPresentScreenAd;

//Optional function to implement something when action of showing advertisment is tiggered
-(void)onActionShow;

//Optional function to implement something when action of opening url is tiggered.
//The url variable contains the opennig url
-(void)onActionUrlOpen:(NSString *)url;

//Optional function to implement something when close button is clicked
-(void)onActionCloseButton;

//Optional function to implement something when the advertisement is closed
-(void)onAdClose;

//Optional function to show the errors
//The error variable contains the explanation of the error
-(void)onError:(NSString *)error;

//Optional function to show Warnings
//The warning variable contains the explanation of the warnings
-(void)onWarning:(NSString *)warning;

@end

//Sps is the advertisement object.
@interface Sps : NSObject < CLLocationManagerDelegate, WKNavigationDelegate, UINavigationControllerDelegate, UITextFieldDelegate, UIGestureRecognizerDelegate>

//Optional value for delegate sps.
@property(nonatomic,assign)id delegate;

//The function to add requiered value created in mobeleader website.
- (void) setAppHash: (NSString *)appHash;

//The function to add optional value for advertisement type.
//De momento el usuario no tendrá la opcion de elegir que tipo de anuncio recoger, solo de tipo banner
- (void) setAdType: (NSUInteger)adType;

//The function to add optional value for the name of the user
- (void) setUserName: (NSString *)uName;

//The function to add optional value for the surname of the user
- (void) setUserSurnames: (NSString *)uSurnames;

//The function to add optional value for the email of the user.
- (void) setUserEmail: (NSString *)uEmail;

//The function to add optional value for the phone of the user.
- (void) setPhoneNumber: (NSString *)uPhoneNumber;

//The function to add optional value for the birth date of the user.
- (void) setUserBirthDate: (NSDate *)uBirthDate;

//The function to add the rootViewController
- (void)setRootViewController:(UIViewController * )rootViewController;

//The function to add the postion of the banner by coordenates
- (void)setAdPosition:(CGPoint )position;

//The function to add the postion of the banner by relative position
- (void)setAdRelativePosition:(NSString* )position;

//The function to add the Space of the Advertisment
- (void)setAppSpace:(UIView *)appSpace;

//The function to open the advertisement
- (void)startSps:(UIView*)sview;

//The function to getReady the advertisment. The advertsiment is not going to show until onAdReadyToShow delegate is called and you call to funtion showAd
- (void)getReady:(UIView*)sview;

//The function to show advertisement when onAdReadyToShow delegate is called. You have to call first getReady function
- (void)showAd;

//The function to clean advertisement
- (void)cleanAds;

//The function to cget the current version of SpS
- (NSString*) getVersion;

//The function is deprecated
- (void)setSentAdId:(NSUInteger)idApp;

// The fucction to get auto-ads
- (void)setAutoAd:(BOOL)isAutoAd;

// The fucction to get testing creatives
- (void)setTestMode:(BOOL)isTestMode;

//The function to add the Space Identifier.
- (void) setAppSpaceHash: (NSString *)spaceHash;

//The function to add the Space Identifier.
- (void) setSpsSize: (NSString *)spsSize;

+(Sps*)shared;

@end




















